Remove all source map files at build time.

For Ionic, ensure the `ionic_generate_source_map` is set to `false`.

If the build is generated from command line, ensure the `--generateSourceMap` flag is set to `false`.